@@ -131,9 +131,15 @@ def get_length(arg):
             total_length += get_length(value)
         return total_length
     if isinstance(arg, astroid.nodes.Subscript):
-        print(arg.lineno)
+        base_length = 2 # brackets
+        total_length = base_length + get_length(arg.value) + get_length(arg.slice)
+        return total_length
+    if isinstance(arg, astroid.nodes.JoinedStr):
+        base_length = 3 # quotes and 'f'
         total_length = 0
-        total_length += get_length(arg.value)
+        for value in arg.values:
+            total_length += get_length(value)
+        total_length += base_length
         return total_length
     print(f"Unhandled {arg}")
     return 0
